// api
export { buildStorage } from './api/buildStorage';
export { createSocket } from './api/socket';
export type { AppSocket } from './api/socket';

// cache
export { getCachedUserInfo } from './cache/cache';
export { useCachedUserInfo } from './cache/useCache';

// components
export {
  FastForm,
  CustomField,
  regField,
  regFormContainer,
} from './components/FastForm/index';
export type {
  FastFormFieldComponent,
  FastFormFieldProps,
  FastFormFieldMeta,
  FastFormContainerComponent,
} from './components/FastForm/index';
export { buildPortal, DefaultEventEmitter } from './components/Portal';
export { TcProvider } from './components/Provider';

// i18n
export { t, setLanguage, useTranslation } from './i18n';

// hooks
export { useAsync } from './hooks/useAsync';
export { useAsyncFn } from './hooks/useAsyncFn';
export { useAsyncRequest } from './hooks/useAsyncRequest';
export { useMountedState } from './hooks/useMountedState';
export { useRafState } from './hooks/useRafState';

// manager
export { getStorage, setStorage, useStorage } from './manager/storage';
export { setTokenGetter } from './manager/request';
export { setServiceUrl } from './manager/service';
export {
  showToasts,
  setToasts,
  showAlert,
  setAlert,
  showErrorToasts,
} from './manager/ui';

// model
export { createDMConverse } from './model/converse';
export {
  addFriendRequest,
  cancelFriendRequest,
  acceptFriendRequest,
  denyFriendRequest,
} from './model/friend';
export type { FriendRequest } from './model/friend';
export { GroupPanelType, createGroup } from './model/group';
export type { GroupPanel, GroupInfo } from './model/group';
export type { ChatMessage } from './model/message';
export type { UserBaseInfo, UserLoginInfo } from './model/user';
export {
  loginWithEmail,
  registerWithEmail,
  searchUserWithUniqueName,
} from './model/user';

// redux
export { useAppSelector, useAppDispatch } from './redux/hooks/useAppSelector';
export { useDMConverseList } from './redux/hooks/useConverse';
export { useConverseMessage } from './redux/hooks/useConverseMessage';
export { useGroupInfo } from './redux/hooks/useGroup';
export { useUserId } from './redux/hooks/useUserInfo';
export { userActions } from './redux/slices';
export type { ChatConverseState } from './redux/slices/chat';
export { setupRedux } from './redux/setup';
export { createStore } from './redux/store';
export type { AppStore, AppDispatch } from './redux/store';

// utils
export {
  shouldShowMessageTime,
  getMessageTimeDiff,
  formatShortTime,
} from './utils/date-helper';
export { isBrowser, isNavigator } from './utils/environment';
export { getTextColorHex } from './utils/string-helper';
